@@ -2,9 +2,10 @@
 
 extern crate test;
 
-use solana_perf::{packet::PacketsRecycler, recycler::Recycler};
-
-use test::Bencher;
+use {
+    solana_perf::{packet::PacketsRecycler, recycler::Recycler},
+    test::Bencher,
+};
 
 #[bench]
 fn bench_recycler(bencher: &mut Bencher) {
